@@ -19,29 +19,16 @@ The penaties should be smooth so that they can be subtracted from log
 likelihood functions and optimized using standard methods (i.e. L1
 penalties do not belong here).
 """
-from __future__ import division
-
 import numpy as np
 
 
-def _check_wts(weights, wts):
-    """helper function for deprecating `wts`
-    """
-    if wts is not None:
-        import warnings
-        warnings.warn('`wts` method is deprecated. Use `weights` instead',
-                      DeprecationWarning)
-    weights = weights if weights is not None else wts
-    return weights
-
-
 class Penalty(object):
     """
     A class for representing a scalar-value penalty.
 
     Parameters
     ----------
-    weights : array-like
+    weights : array_like
         A vector of weights that determines the weight of the penalty
         for each parameter.
 
@@ -50,7 +37,7 @@ class Penalty(object):
     The class has a member called `alpha` that scales the weights.
     """
 
-    def __init__(self, weights):
+    def __init__(self, weights=1.):
         self.weights = weights
         self.alpha = 1.
 
@@ -60,7 +47,7 @@ class Penalty(object):
 
         Parameters
         ----------
-        params : array-like
+        params : array_like
             A vector of parameters.
 
         Returns
@@ -76,7 +63,7 @@ class Penalty(object):
 
         Parameters
         ----------
-        params : array-like
+        params : array_like
             A vector of parameters
 
         Returns
@@ -113,9 +100,10 @@ class NonePenalty(Penalty):
     """
 
     def __init__(self, **kwds):
+        super().__init__()
         if kwds:
             import warnings
-            warnings.warn('keywords will be ignored')
+            warnings.warn('keyword arguments are be ignored')
 
     def func(self, params):
         if params.ndim == 2:
@@ -136,13 +124,8 @@ class L2(Penalty):
     The L2 (ridge) penalty.
     """
 
-    def __init__(self, weights=None, wts=None):
-        weights = _check_wts(weights, wts)  # for deprecation wts
-        if weights is None:
-            self.weights  = 1.
-        else:
-            self.weights  = weights
-        self.alpha = 1.
+    def __init__(self, weights=1.):
+        super().__init__(weights)
 
     def func(self, params):
         return np.sum(self.weights * self.alpha * params**2)
@@ -180,14 +163,9 @@ class PseudoHuber(Penalty):
     The pseudo-Huber penalty.
     """
 
-    def __init__(self, dlt, weights=None, wts=None):
+    def __init__(self, dlt, weights=1.):
+        super().__init__(weights)
         self.dlt = dlt
-        weights = _check_wts(weights, wts)  # for deprecation wts
-        if weights is None:
-            self.weights  = 1.
-        else:
-            self.weights  = weights
-        self.alpha = 1.
 
     def func(self, params):
         v = np.sqrt(1 + (params / self.dlt)**2)
@@ -245,11 +223,8 @@ class SCAD(Penalty):
     1348-1360.
     """
 
-    def __init__(self, tau, c=3.7, weights=None):
-        if weights is None:
-            self.weights = 1.
-        else:
-            self.weights = weights
+    def __init__(self, tau, c=3.7, weights=1.):
+        super().__init__(weights)
         self.tau = tau
         self.c = c
 
@@ -337,15 +312,10 @@ class SCADSmoothed(SCAD):
     -----
     TODO: Use delegation instead of subclassing, so smoothing can be added to
     all penalty classes.
-
     """
 
-    def __init__(self, tau, c=3.7, c0=None, weights=None, restriction=None):
-        if weights is None:
-            self.weights = 1.
-        else:
-            self.weights = weights
-        self.alpha = 1.
+    def __init__(self, tau, c=3.7, c0=None, weights=1., restriction=None):
+        super().__init__(tau, c=c, weights=weights)
         self.tau = tau
         self.c = c
         self.c0 = c0 if c0 is not None else tau * 0.1
@@ -456,7 +426,6 @@ class ConstraintsPenalty(object):
     constraints of the original parameters.
     Examples for these contrast are difference penalities or all pairs
     penalties.
-
     """
 
     def __init__(self, penalty, weights=None, restriction=None):
@@ -549,9 +518,8 @@ class ConstraintsPenalty(object):
         return value
 
 
-class L2ContraintsPenalty(ConstraintsPenalty):
+class L2ConstraintsPenalty(ConstraintsPenalty):
     """convenience class of ConstraintsPenalty with L2 penalization
-
     """
 
     def __init__(self, weights=None, restriction=None, sigma_prior=None):
@@ -561,7 +529,7 @@ class L2ContraintsPenalty(ConstraintsPenalty):
 
         penalty = L2Univariate()
 
-        super(L2ContraintsPenalty, self).__init__(penalty, weights=weights,
+        super(L2ConstraintsPenalty, self).__init__(penalty, weights=weights,
                                                   restriction=restriction)
 
 
