@@ -8,19 +8,21 @@ import textwrap
 from collections import namedtuple
 from collections.abc import Mapping
 
+from statsmodels.tools.sm_exceptions import ParseError
+
 
 def dedent_lines(lines):
     """Deindent a list of lines maximally"""
     return textwrap.dedent("\n".join(lines)).split("\n")
 
 
-def strip_blank_lines(l):
+def strip_blank_lines(line):
     """Remove leading and trailing blank lines from a list of lines"""
-    while l and not l[0].strip():
-        del l[0]
-    while l and not l[-1].strip():
-        del l[-1]
-    return l
+    while line and not line[0].strip():
+        del line[0]
+    while line and not line[-1].strip():
+        del line[-1]
+    return line
 
 
 class Reader(object):
@@ -46,34 +48,34 @@ class Reader(object):
         return self._str[n]
 
     def reset(self):
-        self._l = 0  # current line nr
+        self._line_num = 0  # current line nr
 
     def read(self):
         if not self.eof():
-            out = self[self._l]
-            self._l += 1
+            out = self[self._line_num]
+            self._line_num += 1
             return out
         else:
             return ''
 
     def seek_next_non_empty_line(self):
-        for l in self[self._l:]:
-            if l.strip():
+        for line in self[self._line_num:]:
+            if line.strip():
                 break
             else:
-                self._l += 1
+                self._line_num += 1
 
     def eof(self):
-        return self._l >= len(self._str)
+        return self._line_num >= len(self._str)
 
     def read_to_condition(self, condition_func):
-        start = self._l
+        start = self._line_num
         for line in self[start:]:
             if condition_func(line):
-                return self[start:self._l]
-            self._l += 1
+                return self[start:self._line_num]
+            self._line_num += 1
             if self.eof():
-                return self[start:self._l + 1]
+                return self[start:self._line_num + 1]
         return []
 
     def read_to_next_empty_line(self):
@@ -91,8 +93,8 @@ class Reader(object):
         return self.read_to_condition(is_unindented)
 
     def peek(self, n=0):
-        if self._l + n < len(self._str):
-            return self[self._l + n]
+        if self._line_num + n < len(self._str):
+            return self[self._line_num + n]
         else:
             return ''
 
@@ -100,14 +102,6 @@ class Reader(object):
         return not ''.join(self._str).strip()
 
 
-class ParseError(Exception):
-    def __str__(self):
-        message = self.args[0]
-        if hasattr(self, 'docstring'):
-            message = "%s in %r" % (message, self.docstring)
-        return message
-
-
 Parameter = namedtuple('Parameter', ['name', 'type', 'desc'])
 
 
@@ -288,7 +282,7 @@ class NumpyDocString(Mapping):
             """Match ':role:`name`' or 'name'."""
             m = self._func_rgx.match(text)
             if not m:
-                raise ParseError("%s is not a item name" % text)
+                raise ParseError(f"{text} is not a item name")
             role = m.group('role')
             name = m.group('name') if role else m.group('name2')
             return name, role, m.end()
@@ -323,7 +317,7 @@ class NumpyDocString(Mapping):
                 rest = list(filter(None, [description]))
                 items.append((funcs, rest))
             else:
-                raise ParseError("%s is not a item name" % line)
+                raise ParseError(f"{line} is not a item name")
         return items
 
     def _parse_index(self, section, content):
@@ -618,7 +612,8 @@ class Docstring(object):
         if block_name not in self._ds:
             raise ValueError('{0} is not a block in the '
                              'docstring'.format(block_name))
-        if not isinstance(block, list):
+        if not isinstance(block, list) and \
+                isinstance(self._ds[block_name], list):
             block = [block]
         self._ds[block_name] = block
 
