@@ -3,17 +3,11 @@
 Impulse reponse-related code
 """
 
-from __future__ import division
-
 import numpy as np
 import numpy.linalg as la
 import scipy.linalg as L
 
-
 from statsmodels.tools.decorators import cache_readonly
-from statsmodels.tools.tools import chain_dot
-#from statsmodels.tsa.api import VAR
-from statsmodels.compat.python import range
 import statsmodels.tsa.tsatools as tsa
 import statsmodels.tsa.vector_ar.plotting as plotting
 import statsmodels.tsa.vector_ar.util as util
@@ -92,10 +86,10 @@ class BaseIRAnalysis(object):
     def cum_effect_cov(self, *args, **kwargs):
         raise NotImplementedError
 
-    def plot(self, orth=False, impulse=None, response=None,
-             signif=0.05, plot_params=None, subplot_params=None,
-             plot_stderr=True, stderr_type='asym', repl=1000,
-             seed=None, component=None):
+    def plot(self, orth=False, *, impulse=None, response=None,
+             signif=0.05, plot_params=None, figsize=(10, 10),
+             subplot_params=None, plot_stderr=True, stderr_type='asym',
+             repl=1000, seed=None, component=None):
         """
         Plot impulse responses
 
@@ -103,9 +97,9 @@ class BaseIRAnalysis(object):
         ----------
         orth : bool, default False
             Compute orthogonalized impulse responses
-        impulse : string or int
+        impulse : {str, int}
             variable providing the impulse
-        response : string or int
+        response : {str, int}
             variable affected by the impulse
         signif : float (0 < signif < 1)
             Significance level for error bars, defaults to 95% CI
@@ -114,14 +108,16 @@ class BaseIRAnalysis(object):
             pass {'fontsize' : 8} or some number to your taste.
         plot_params : dict
 
-        plot_stderr: bool, default True
+        figsize : (float, float), default (10, 10)
+            Figure size (width, height in inches)
+        plot_stderr : bool, default True
             Plot standard impulse response error bands
-        stderr_type: string
+        stderr_type : str
             'asym': default, computes asymptotic standard errors
             'mc': monte carlo standard errors (use rpl)
-        repl: int, default 1000
+        repl : int, default 1000
             Number of replications for Monte Carlo and Sims-Zha standard errors
-        seed: int
+        seed : int
             np.random.seed for Monte Carlo replications
         component: array or vector of principal component indices
         """
@@ -172,11 +168,12 @@ class BaseIRAnalysis(object):
                                      self.model.names, title, signif=signif,
                                      subplot_params=subplot_params,
                                      plot_params=plot_params,
+                                     figsize=figsize,
                                      stderr_type=stderr_type)
         return fig
 
-    def plot_cum_effects(self, orth=False, impulse=None, response=None,
-                         signif=0.05, plot_params=None,
+    def plot_cum_effects(self, orth=False, *, impulse=None, response=None,
+                         signif=0.05, plot_params=None, figsize=(10, 10),
                          subplot_params=None, plot_stderr=True,
                          stderr_type='asym', repl=1000, seed=None):
         """
@@ -186,9 +183,9 @@ class BaseIRAnalysis(object):
         ----------
         orth : bool, default False
             Compute orthogonalized impulse responses
-        impulse : string or int
+        impulse : {str, int}
             variable providing the impulse
-        response : string or int
+        response : {str, int}
             variable affected by the impulse
         signif : float (0 < signif < 1)
             Significance level for error bars, defaults to 95% CI
@@ -197,16 +194,17 @@ class BaseIRAnalysis(object):
             pass {'fontsize' : 8} or some number to your taste.
         plot_params : dict
 
-        plot_stderr: bool, default True
+        figsize: (float, float), default (10, 10)
+            Figure size (width, height in inches)
+        plot_stderr : bool, default True
             Plot standard impulse response error bands
-        stderr_type: string
+        stderr_type : str
             'asym': default, computes asymptotic standard errors
             'mc': monte carlo standard errors (use rpl)
-        repl: int, default 1000
+        repl : int, default 1000
             Number of replications for monte carlo standard errors
-        seed: int
+        seed : int
             np.random.seed for Monte Carlo replications
-
         """
 
         if orth:
@@ -234,6 +232,7 @@ class BaseIRAnalysis(object):
                                      hlines=lr_effects,
                                      subplot_params=subplot_params,
                                      plot_params=plot_params,
+                                     figsize=figsize,
                                      stderr_type=stderr_type)
         return fig
 
@@ -283,7 +282,7 @@ class IRAnalysis(BaseIRAnalysis):
         covs[0] = np.zeros((self.neqs ** 2, self.neqs ** 2))
         for i in range(1, self.periods + 1):
             Gi = self.G[i - 1]
-            covs[i] = chain_dot(Gi, self.cov_a, Gi.T)
+            covs[i] = Gi @ self.cov_a @ Gi.T
 
         return covs
 
@@ -512,7 +511,6 @@ class IRAnalysis(BaseIRAnalysis):
         W: array of eigenvectors
         eigva: list of eigenvalues
         k: matrix indicating column # of largest eigenvalue for each c_i,j
-
         """
         neqs = self.neqs
         periods = self.periods
@@ -575,10 +573,10 @@ class IRAnalysis(BaseIRAnalysis):
                 apiece = 0
             else:
                 Ci = np.dot(PIk, self.G[i-1])
-                apiece = chain_dot(Ci, self.cov_a, Ci.T)
+                apiece = Ci @ self.cov_a @ Ci.T
 
             Cibar = np.dot(np.kron(Ik, self.irfs[i]), H)
-            bpiece = chain_dot(Cibar, self.cov_sig, Cibar.T) / self.T
+            bpiece = (Cibar @ self.cov_sig @ Cibar.T) / self.T
 
             # Lutkepohl typo, cov_sig correct
             covs[i] = apiece + bpiece
@@ -592,7 +590,7 @@ class IRAnalysis(BaseIRAnalysis):
 
         Parameters
         ----------
-        orth : boolean
+        orth : bool
 
         Notes
         -----
@@ -600,7 +598,6 @@ class IRAnalysis(BaseIRAnalysis):
 
         Returns
         -------
-
         """
         Ik = np.eye(self.neqs)
         PIk = np.kron(self.P.T, Ik)
@@ -616,10 +613,10 @@ class IRAnalysis(BaseIRAnalysis):
                     apiece = 0
                 else:
                     Bn = np.dot(PIk, F)
-                    apiece = chain_dot(Bn, self.cov_a, Bn.T)
+                    apiece = Bn @ self.cov_a @ Bn.T
 
                 Bnbar = np.dot(np.kron(Ik, self.cum_effects[i]), self.H)
-                bpiece = chain_dot(Bnbar, self.cov_sig, Bnbar.T) / self.T
+                bpiece = (Bnbar @ self.cov_sig @ Bnbar.T) / self.T
 
                 covs[i] = apiece + bpiece
             else:
@@ -627,7 +624,7 @@ class IRAnalysis(BaseIRAnalysis):
                     covs[i] = np.zeros((self.neqs**2, self.neqs**2))
                     continue
 
-                covs[i] = chain_dot(F, self.cov_a, F.T)
+                covs[i] = F @ self.cov_a @ F.T
 
         return covs
 
@@ -645,7 +642,6 @@ class IRAnalysis(BaseIRAnalysis):
         """
         Returns
         -------
-
         """
         lre = self.lr_effects
         Finfty = np.kron(np.tile(lre.T, self.lags), lre)
@@ -655,10 +651,10 @@ class IRAnalysis(BaseIRAnalysis):
             Binf = np.dot(np.kron(self.P.T, np.eye(self.neqs)), Finfty)
             Binfbar = np.dot(np.kron(Ik, lre), self.H)
 
-            return (chain_dot(Binf, self.cov_a, Binf.T) +
-                    chain_dot(Binfbar, self.cov_sig, Binfbar.T))
+            return (Binf @ self.cov_a @ Binf.T +
+                    Binfbar @ self.cov_sig @ Binfbar.T)
         else:
-            return chain_dot(Finfty, self.cov_a, Finfty.T)
+            return Finfty @ self.cov_a @ Finfty.T
 
     def stderr(self, orth=False):
         return np.array([tsa.unvec(np.sqrt(np.diag(c)))
@@ -683,14 +679,11 @@ class IRAnalysis(BaseIRAnalysis):
         Kkk = tsa.commutation_matrix(k, k)
         Ik = np.eye(k)
 
-        # B = chain_dot(Lk, np.eye(k**2) + commutation_matrix(k, k),
-        #               np.kron(self.P, np.eye(k)), Lk.T)
+        # B = Lk @ (np.eye(k**2) + commutation_matrix(k, k)) @ \
+        #     np.kron(self.P, np.eye(k)) @ Lk.T
+        # return Lk.T @ L.inv(B)
 
-        # return np.dot(Lk.T, L.inv(B))
-
-        B = chain_dot(Lk,
-                      np.dot(np.kron(Ik, self.P), Kkk) + np.kron(self.P, Ik),
-                      Lk.T)
+        B = Lk @ (np.kron(Ik, self.P) @ Kkk + np.kron(self.P, Ik)) @ Lk.T
 
         return np.dot(Lk.T, L.inv(B))
 
